<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Fet</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../obconf.ui" line="63"/>
        <source>Mouse</source>
        <translation>Mus</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="14"/>
        <source>Window Manager Preferences</source>
        <translation>Inställningar för fönstehanteraren</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="38"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="43"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="48"/>
        <source>Font</source>
        <translation>Teckensnitt</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="53"/>
        <location filename="../obconf.ui" line="114"/>
        <source>Windows</source>
        <translation>Fönster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="58"/>
        <source>Move &amp; Resize</source>
        <translation>Flytta och byt storlek</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="68"/>
        <source>Desktops</source>
        <translation>Skrivbord</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="73"/>
        <source>Margins</source>
        <translation>Marginaler</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="78"/>
        <source>Dock</source>
        <translation>Docka</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="137"/>
        <source>Window Titles</source>
        <translation>Fönsternamn</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="143"/>
        <source>Button order:</source>
        <translation>Knappordning:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="439"/>
        <source>Moving and Resizing Windows</source>
        <translation>Flytta och storleksändra fönster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="542"/>
        <source>Information Dialog</source>
        <translation>Informationsruta</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="701"/>
        <source>Focusing Windows</source>
        <translation>Fokusera fönster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="710"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Fokusera fönster när muspekaren flyttas över dem</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="768"/>
        <source>Titlebar</source>
        <translation>Namnlist</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="905"/>
        <source>Desktop Margins</source>
        <translation>Marginaler på skrivbordet</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="911"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>Marginaler på skrivbordet reserveras vid kanten på skärmen.  Nya fönster kommer inte att placeras inom marginalen och maximerade fönster kommer inte att täcka dessa.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="921"/>
        <source>Left:</source>
        <translation>Vänster:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="935"/>
        <location filename="../obconf.ui" line="956"/>
        <location filename="../obconf.ui" line="977"/>
        <location filename="../obconf.ui" line="998"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="942"/>
        <source>Top:</source>
        <translation>Överst:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="963"/>
        <source>Right:</source>
        <translation>Höger:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="984"/>
        <source>Bottom:</source>
        <translation>Nederst:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="329"/>
        <source>All monitors</source>
        <translation>Alla bildskärmar</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="334"/>
        <source>The active monitor</source>
        <translation>Aktiv bildskärm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="339"/>
        <source>The monitor with the mouse</source>
        <translation>Bildskärmen med musen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="354"/>
        <source>Primary Monitor</source>
        <translation>Primär bildskärm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="360"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>Primär bildskärm som Openbox ska placera dialogrutor på, exempelvis den som används för rotera genom fönster.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="381"/>
        <source>Fixed Monitor</source>
        <translation>Fast bildskärm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="386"/>
        <source>Active Monitor</source>
        <translation>Aktiv bildskärm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="391"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Bildskärm med muspekare</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="549"/>
        <location filename="../obconf.ui" line="578"/>
        <source>Centered</source>
        <translation>Centrerat</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="554"/>
        <source>From left edge</source>
        <translation>Från vänsterkant</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="559"/>
        <source>From right edge</source>
        <translation>Från högerkant</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="583"/>
        <source>From top edge</source>
        <translation>Från överkant</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="588"/>
        <source>From bottom edge</source>
        <translation>Från nederkant</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="641"/>
        <source>When resizing terminal windows</source>
        <translation>När storlek på terminalfönster ändras</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="646"/>
        <source>Always</source>
        <translation>Alltid</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="651"/>
        <source>Never</source>
        <translation>Aldrig</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="660"/>
        <source>Centered on the window</source>
        <translation>Centrerat på fönster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="665"/>
        <source>Above the window</source>
        <translation>Ovanför fönster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="670"/>
        <source>Fixed position on screen</source>
        <translation>Fast position på skärmen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="785"/>
        <source>Maximizes the window</source>
        <translation>Maximerar fönstret</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="790"/>
        <source>Shades the window</source>
        <translation>Skuggar fönstret</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="153"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Fönsterikon
L: Fönstertitel
I: Ikonifiera/Minimera
M: Maximera
C: Stäng
S: Rulla upp
D: På alla skrivbord</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="344"/>
        <source>Primary monitor</source>
        <translation>Primär bildskärm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1025"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1041"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1053"/>
        <source>&amp;Position:</source>
        <translation>&amp;Position:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1067"/>
        <source>Top Left</source>
        <translation>Övre vänster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1072"/>
        <source>Top</source>
        <translation>Övre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1077"/>
        <source>Top Right</source>
        <translation>Övre höger</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1082"/>
        <source>Left</source>
        <translation>Vänster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1087"/>
        <source>Right</source>
        <translation>Höger</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1092"/>
        <source>Bottom Left</source>
        <translation>Nedre vänster</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1097"/>
        <source>Bottom</source>
        <translation>Nedre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1102"/>
        <source>Bottom Right</source>
        <translation>Nedre höger</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1107"/>
        <source>Floating</source>
        <translation>Flytande</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1121"/>
        <source>&amp;Floating position:</source>
        <translation>&amp;Flytande position:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1146"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1162"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1169"/>
        <source>&amp;Orientation: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1183"/>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1188"/>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1199"/>
        <source>Stacking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1205"/>
        <source>Keep dock &amp;above other windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1212"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1219"/>
        <source>Keep dock &amp;below other windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1229"/>
        <source>Hiding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1235"/>
        <source>&amp;Delay before hiding:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1245"/>
        <source>Delay before &amp;showing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1275"/>
        <source>&amp;Hide off screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1306"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="96"/>
        <source>&amp;Install a new theme...</source>
        <translation>&amp;Installera ett nytt tema...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="103"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Skapa ett tema&amp;arkiv (.obt)...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="120"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>&amp;Fönster behåller kan även utan dekoration</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="127"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>A&amp;nimera ikonifiering och återställning</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="231"/>
        <source>&amp;Active window title: </source>
        <translation>&amp;Aktiv fönstertitel: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="241"/>
        <source>&amp;Inactive window title: </source>
        <translation>&amp;Inaktiv fönstertitel: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="251"/>
        <source>Menu &amp;header: </source>
        <translation>&amp;Huvudmeny: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="261"/>
        <source>&amp;Menu Item: </source>
        <translation>&amp;Menyalternativ: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="271"/>
        <source>Active &amp;On-screen display: </source>
        <translation>Aktiv &amp;On-screen-display: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="281"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>Inaktiv O&amp;n-screen-display: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="295"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>Fokusera &amp;nya fönster när de dyker upp</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="302"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>&amp;Placera nya fönster under muspekaren</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="309"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>&amp;Centrera nya fönster när de placeras</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="318"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>Föredra att placera nya fönster &amp;på:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="370"/>
        <source>Primary &amp;monitor:</source>
        <translation>Primär &amp;bildskärm:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="399"/>
        <source>&amp;Fixed monitor:</source>
        <translation>&amp;Fast bildskräm:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="445"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Uppdatera fönsterinnehåll när det ändrar &amp;storlek</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="452"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>&amp;Tröskelvärde för distans att dra:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="472"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Motstånd mot andra &amp;fönster:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="492"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>Motstånd mot &amp;skärmkanten:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="512"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>&amp;Tid att vänta innan byte:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="532"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>&amp;Byt skrivbord när fönster flyttas över kanten</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="567"/>
        <source>Fixed &amp;y position:</source>
        <translation>Fast &amp;y-position:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="596"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>Informationsrutans &amp;position:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="606"/>
        <source>Fixed &amp;x position:</source>
        <translation>Fast &amp;x-position:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="616"/>
        <source>Show &amp;information dialog:</source>
        <translation>Visa &amp;informationsruta:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="722"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>&amp;Dröj innan fokusering och framhävning av fönster:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="742"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>Flytta fokus under musen när &amp;skrivbordsbyte sker</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="749"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>Flytta fokus &amp;under musen när musen inte flyttas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="756"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>&amp;Framhäv fönster när muspekaren flyttas över de</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="774"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Dubbelklick på fönstertiteln:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="798"/>
        <source>Double click ti&amp;me:</source>
        <translation>Tid för &amp;dubbelklick:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="838"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>Vi&amp;sa notifiering vid byte av skrivbord</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="845"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>&amp;Tid som notifiering visas:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="868"/>
        <source>&amp;Number of desktops: </source>
        <translation>&amp;Antal skrivbord: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="891"/>
        <source>&amp;Desktop names:</source>
        <translation>&amp;Skrivbordsnamn:</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../mouse.cpp" line="57"/>
        <source>Custom actions</source>
        <translation>Anpassade åtgärder</translation>
    </message>
    <message>
        <location filename="../desktops.cpp" line="65"/>
        <location filename="../desktops.cpp" line="87"/>
        <location filename="../desktops.cpp" line="99"/>
        <source>(Unnamed desktop)</source>
        <translation>(Skrivbord utan namn)</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="76"/>
        <source>About ObConf-Qt</source>
        <translation>Om ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="77"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../theme.cpp" line="149"/>
        <source>Choose an Openbox theme</source>
        <translation>Välj Openbox-tema</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %2</source>
        <translation type="unfinished">&quot;%2&quot; installerades på %2 {1&quot;?}</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>&quot;%1&quot; skapades</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>Kunde inte skapa temaarkivet &quot;%1&quot;.
Följande fel rapporterades:
%2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="95"/>
        <location filename="../archive.cpp" line="178"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>Kunde inte köra tar-kommandot: %1</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Kunde inte skapa katalogen &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>&quot;%1&quot; verkar inte vara en korrekt temakatalog för Openbox</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="148"/>
        <source>Unable to move to directory &quot;%1&quot;: %2</source>
        <translation>Kunde inte flytta till katalog &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="185"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>Kunde inte packa upp filen &quot;%1&quot;.
Tillse att &quot;%2&quot; är skrivbar och att filen är ett korrekt temaarkiv för Openbox.
Följande fel rapporterades:
%3</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>ObConf Fel</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Användning: obconf [flagga] [ARKIV.obt]

Flaggor:
  --help                Visar denna hjälptext och avslutar
  --version             Visar version och avslutar
  --install ARKIV.obt Installarerar angivet temaarkiv och väljer det
  --archive TEMA       Skapar ett temaarkiv för angiven temakatalog
  --config-file FIL    Anger sökvägen till inställningsfilen som ska användas
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install behöver ett argument
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--archive behöver ett argument
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file behöver ett argument
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="223"/>
        <location filename="../obconf-qt.cpp" line="238"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="224"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Kunde inte läsa rc.xml. Troligen är inte Openbox korrekt installerat.</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="236"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Fel vid läsning av inställningsfilen för Openbox.  Din inställningsfil är inte korrekt XML.

Meddelande: %1</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Copyright © 2003-2008   Dana Jansens
Copyright © 2003        Tim Riley
Copyright © 2007        Javeed Shaikh
Copyright © 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</translation>
    </message>
</context>
</TS>
